@@ -1,7 +1,5 @@
 package Chart::Clicker::Axis;
-{
-  $Chart::Clicker::Axis::VERSION = '2.86';
-}
+$Chart::Clicker::Axis::VERSION = '2.87';
 use Moose;
 use Moose::Util;
 
@@ -166,7 +164,7 @@ has 'tick_values' => (
 );
 
 
-has 'ticks' => ( is => 'rw', isa => 'Int', default => 5 );
+has 'ticks' => ( is => 'rw', isa => 'Int', default => 6 );
 
 sub BUILD {
     my ($self) = @_;
@@ -580,7 +578,7 @@ Chart::Clicker::Axis - An X or Y Axis
 
 =head1 VERSION
 
-version 2.86
+version 2.87
 
 =head1 SYNOPSIS
 
@@ -620,7 +618,7 @@ Selects the algorithm for dividing the graph axis into labelled ticks.
 
 The currently included algorithms are:
 L<Chart::Clicker::Data::DivisionType::Exact/Exact>,
-L<Chart::Clicker::Data::DivisionType::RoundedLinear/RoundedLinear>.
+L<Chart::Clicker::Data::DivisionType::LinearRounded/LinearRounded>.
 
 You may write your own by providing a Moose Role which includes Role
 L<Chart::Clicker::Data::DivisionType> and prefixing the module name
@@ -787,7 +785,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Cold Hard Code, LLC.
+This software is copyright (c) 2014 by Cold Hard Code, LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
