@@ -1,14 +1,12 @@
 package Chart::Clicker::Positioned;
-{
-  $Chart::Clicker::Positioned::VERSION = '2.86';
-}
+$Chart::Clicker::Positioned::VERSION = '2.87';
 use Moose::Role;
 
 # ABSTRACT: Role for components that care about position.
 
 use Moose::Util::TypeConstraints;
 
-enum 'Chart::Clicker::Position' => qw(left right top bottom);
+enum 'Chart::Clicker::Position' => [qw(left right top bottom)];
 
 
 has 'position' => (
@@ -57,7 +55,7 @@ Chart::Clicker::Positioned - Role for components that care about position.
 
 =head1 VERSION
 
-version 2.86
+version 2.87
 
 =head1 SYNOPSIS
 
@@ -107,7 +105,7 @@ Cory G Watson <gphat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Cold Hard Code, LLC.
+This software is copyright (c) 2014 by Cold Hard Code, LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
